@@ -1,6 +1,6 @@
 "Common functions that may be used everywhere"
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import os
 import sys
