@@ -1,6 +1,6 @@
 "Livestreamer main class"
 
-from __future__ import print_function, division
+from __future__ import division, print_function, unicode_literals
 
 import os
 import re
@@ -66,13 +66,18 @@ class LivestreamerDumper(object):
     "Main class for dumping streams"
 
     def __init__(self, config_path):
+        """LivestreamerDumper constructor
+
+        Parameters:
+        config_path: path to user config directory
+        """
         self.fd = None
         self.config_path = config_path
 
     def open(self, url, quality):
-        """Attempt to open stream from the *url*.
+        """Attempt to open stream from *url*.
 
-        Exits with '-1' (using sys.exit()) in case of error, including
+        Exits with '-1' (using self.exit()) in case of error, including
         an error msg.
         """
 
@@ -121,8 +126,26 @@ class LivestreamerDumper(object):
 
 
     def get_title(self):
-        """Returns the end of video url to be used as a title, for
-        example: http://www.example.com/path1/path2?q=V1 -> path2_q=V1
+        """Returns the filename from URL (including extension), that
+        may be:
+
+        https://www.youtube.com/watch?v=ZEtEH-GIAJE ->
+        '[Hatsune Miku] After Rain Sweet*Drops [English Sub] -
+        YouTube.mp4'
+
+        https://www.youtube.com/watch?v=ZEtEH-GIAJE ->
+        'watch_v=ZEtEH-GIAJE.mp4'
+
+        The former case occurs when URL is a web page with <title> tags.
+        The last case will occur in pages with malformed HTML or when
+        you pass a non-HTML URL as a parameter (for example, a link to
+        a direct HTML5 video).
+
+        The extension will be detected according to the stream type,
+        for example RTMPStream will always be '.flv'. The only format
+        that may returns a wrong extension is HTTPStream, since there
+        is no standard container in this case. We assume (for now) that
+        every HTTPStream is '.mp4'.
         """
 
         stream_type = self.stream.__class__.__name__
@@ -158,7 +181,7 @@ class LivestreamerDumper(object):
         return filename[:80] + extension
 
     def stop(self):
-        "Close current opened file"
+        "If stream is opened, close it"
 
         if self.fd:
             self.fd.close()
@@ -166,7 +189,7 @@ class LivestreamerDumper(object):
         self.fd = None
 
     def exit(self, msg=''):
-        "Close an opened file and call sys.exit(msg)."
+        "Close an opened stream and call sys.exit(msg)."
 
         self.stop()
         sys.exit(msg)
